/*
** Module   : CommonLastEvent.java
** Abstract : Define all APIs available via the LAST-EVENT system handle.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20130112 Created initial version.
** 002 CA  20130221 Added support for LABEL attribute (not supported attributes call appropriate
**                  API to show error).
** 003 CA  20130927 Added LegacyResource annotation, to determine resource type.
** 004 EVL 20131008 Adding legacy attributes and methods annotation.
*/

package com.goldencode.p2j.util;

/**
 * Exposes the following methods or attributes from the LAST-EVENT handle:
 * <table>
 * <tr>
 *    <th>LAST-EVENT attribute or method</th>
 *    <th>API</th>
 * </tr>
 * <tr>
 *    <td>CODE</td>
 *    <td>{@link #getLastKey()}</td>
 * </tr>
 * <tr>
 *    <td>FUNCTION</td>
 *    <td>{@link #getLastFunction()}</td>
 * </tr>
 * </table>
 * This interface is used as a returned type by the 
 * {@link handle#unwrapLastEvent(handle)} API, which, depending on the 
 * handle's state, it either returns an {@link KeyReader#asHandle()} 
 * instance or a dynamic proxy using {@link handle#invalidAttrAccessProxy}. 
 */
@LegacyResource(resource = LegacyResource.PSEUDO_WIDGET)
public interface CommonLastEvent
extends CommonHandle,
        CommonField
{
   /**
    * Obtains the last key read from any source (stream or terminal).
    *
    * @return   The last key read.
    */
   @LegacyAttribute(name = "CODE")
   public int getLastKey();

   /**
    * Implementation of the LAST-EVENT system handle's FUNCTION attribute.
    *
    * @return   The key function of the last key event.
    */
   @LegacyAttribute(name = "FUNCTION")
   public character getLastFunction();
}
