/*
** Module   : Sensitive.java
** Abstract : An interface for holding the sensitive attribute related methods.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 CS  20130204 Created initial version.
** 002 EVL 20130911 Adding legacy attributes and methods annotation.
*/

package com.goldencode.p2j.util;

/**
 * Provide access to the SENSITIVE handle attribute
 */
public interface Sensitive
{
   /**
    * Java implementation for retrieving the  SENSITIVE  attribute which
    * contains a <code>logical</code> value that tells if the handle can 
    * receive focus or events.
    * <p>
    * If <code>false</code> the response procedure will not be executed.
    * 
    * @return The logical value of the socket which determines if the SOCKET 
    *         can receive and handle events.
    */
   @LegacyAttribute(name = "SENSITIVE")
   public logical isSensitive();
   
   /**
    * Java implementation for getting the  SENSITIVE  attribute which
    * contains a <code>logical</code> value that tells if the handle can 
    * receive focus or events.
    * <p>
    * If set to <code>false</code> the response procedure will not be executed.
    * 
    * @param sensitive
    *        The logical value which the socket which determines if the SOCKET 
    *        can receive and handle events to be set.
    */
   @LegacyAttribute(name = "SENSITIVE", setter = true)
   public void setSensitive(String sensitive);
   
   /**
    * Java implementation for getting the  SENSITIVE  attribute which
    * contains a <code>logical</code> value that tells if the handle can 
    * receive focus or events
    * <p>
    * If set to <code>false</code> the response procedure will not be executed.
    * 
    * @param sensitive
    *        The logical value which the socket which determines if the SOCKET 
    *        can receive and handle events to be set.
    */
   @LegacyAttribute(name = "SENSITIVE", setter = true)
   public void setSensitive(character sensitive);
   
   /**
    * Java implementation for getting the  SENSITIVE  attribute which
    * contains a <code>logical</code> value that tells if the handle can 
    * receive focus or events
    * <p>
    * If set to <code>false</code> the response procedure will not be executed.
    * 
    * @param sensitive
    *        The logical value which the socket which determines if the SOCKET 
    *        can receive and handle events to be set.
    */
   @LegacyAttribute(name = "SENSITIVE", setter = true)
   public void setSensitive(logical sensitive);
   
   /**
    * Java implementation for getting the  SENSITIVE  attribute which
    * contains a <code>logical</code> value that tells if the handle can 
    * receive focus or events
    * <p>
    * If set to <code>false</code> the response procedure will not be executed.
    * 
    * @param sensitive
    *        The logical value which the socket which determines if the SOCKET 
    *        can receive and handle events to be set.
    */
   @LegacyAttribute(name = "SENSITIVE", setter = true)
   public void setSensitive(boolean sensitive);
}
